use strict;
use warnings;

package Jifty::Plugin::SkeletonApp;
use base qw/Jifty::Plugin/;

=head1 NAME

Jifty::Plugin::SkeletonApp - Skeleton for your application

=head1 DESCRIPTION

=cut

1;
